@@ -15,6 +15,14 @@
 #include <sys/utsname.h>
 #include <debian-installer.h>
 
+#ifdef LOCK_DEBUG
+#  define STATUS_LOCK() fprintf(stderr, "%d(%d): trying to lock status file\n", getpid(),__LINE__); status_lock(); fprintf(stderr, "%d(%d): locked\n", getpid(),__LINE__)
+#  define STATUS_UNLOCK() fprintf(stderr, "%d(%d): trying to unlock status file\n", getpid(),__LINE__); status_unlock(); fprintf(stderr, "%d(%d): unlocked\n", getpid(),__LINE__)
+#else
+#  define STATUS_LOCK() status_lock()
+#  define STATUS_UNLOCK() status_unlock()
+#endif
+
 static int force_configure = 0;
 static int loadtemplate = 1;
 
@@ -450,12 +458,14 @@ static int dpkg_unpack(struct package_t *pkgs)
 {
 	int r = 0;
 	struct package_t *pkg;
+	STATUS_LOCK();
 	void *status = status_read();
 
 	if (di_exec_shell_log("rm -rf -- " DPKGCIDIR) != 0 ||
 	    mkdir(DPKGCIDIR, S_IRWXU) != 0)
 	{
 		perror("mkdir");
+		STATUS_UNLOCK();
 		return 1;
 	}
 	
@@ -468,6 +478,7 @@ static int dpkg_unpack(struct package_t *pkgs)
 	status_merge(status, pkgs);
 	if (di_exec_shell_log("rm -rf -- " DPKGCIDIR) != 0)
 		r = 1;
+	STATUS_UNLOCK();
 	return r;
 }
 
@@ -476,7 +487,9 @@ static int dpkg_configure(struct package_t *pkgs)
 	int r = 0;
 	void *found;
 	struct package_t *pkg;
+	STATUS_LOCK();
 	void *status = status_read();
+	STATUS_UNLOCK();
 	for (pkg = pkgs; pkg != 0 && r == 0; pkg = pkg->next)
 	{
 		found = tfind(pkg, &status, package_compare);
@@ -492,18 +505,22 @@ static int dpkg_configure(struct package_t *pkgs)
 			r = dpkg_doconfigure(*(struct package_t **)found);
 		}
 	}
+	STATUS_LOCK();
 	status_merge(status, 0);
+	STATUS_UNLOCK();
 	return r;
 }
 
 static int dpkg_install(struct package_t *pkgs)
 {
 	struct package_t *p, *ordered = 0;
+	STATUS_LOCK();
 	void *status = status_read();
 	if (di_exec_shell_log("rm -rf -- " DPKGCIDIR) != 0 ||
 	    mkdir(DPKGCIDIR, S_IRWXU) != 0)
 	{
 		perror("mkdir");
+		STATUS_UNLOCK();
 		return 1;
 	}
 	
@@ -542,6 +559,7 @@ static int dpkg_install(struct package_t *pkgs)
 	
 	if (ordered != 0)
 		status_merge(status, pkgs);
+	STATUS_UNLOCK();
 	return di_exec_shell_log("rm -rf -- " DPKGCIDIR);
 }
 
@@ -602,6 +620,7 @@ static int dpkg_remove(struct package_t *pkgs)
 	struct package_t *p;
 	char buf[1024], buf2[1024];
 	FILE *fp;
+	STATUS_LOCK();
 	void *status = status_read();
 
 	for (p = pkgs; p != 0; p = p->next)
@@ -650,6 +669,7 @@ static int dpkg_remove(struct package_t *pkgs)
 		  p->status |= STATUS_STATUSHALFINSTALLED;
 	}
 	status_merge(status, pkgs);
+	STATUS_UNLOCK();
 	return r;
 #else
 	FPRINTF(stderr, "udpkg: No support for -r.\n");
